HydroTrack - Python Framework for Tracking and Forecasting Clusters
=====================================================================

.. list-table::
    :stub-columns: 1
    :widths: 10 90

    * - docs
      - |stable| |colab| |gallery|
    * - status
      - |test| |docs|
    * - package
      - |conda| |pypi|
    * - info
      - |contributors| |downloads| |license|


.. |stable| image:: https://img.shields.io/badge/docs-stable-blue.svg
    :alt: Stable
    :target: https://hydrotrack.readthedocs.io

.. |colab| image:: https://colab.research.google.com/assets/colab-badge.svg
    :alt: Open In Colab
    :target: https://colab.research.google.com/github/hydrotrack-project/hydrotrack/blob/main/examples/1_Introducing-Hydrotrack.ipynb

.. |gallery| image:: https://img.shields.io/badge/gallery-examples-blue.svg
    :alt: Gallery
    :target: https://hydrotrack.readthedocs.io/en/latest/gallery/index.html

.. |test| image:: https://www.repostatus.org/badges/latest/active.svg
    :alt: Tests
    :target: https://www.repostatus.org/#active

.. |docs| image:: https://readthedocs.org/projects/hydrotrack/badge/?version=latest
    :alt: Documentation Status
    :target: https://hydrotrack.readthedocs.io/

.. |pypi| image:: https://badge.fury.io/py/hydrotrack.svg
    :alt: PyPI
    :target: https://pypi.python.org/pypi/hydrotrack

.. |conda| image:: https://anaconda.org/hydrotrack/hydrotrack/badges/version.svg
    :alt: Conda
    :target: https://anaconda.org/hydrotrack/hydrotrack

.. |contributors| image:: https://img.shields.io/github/contributors/hydrotrack-project/hydrotrack.svg
    :alt: Contributors
    :target: https://github.com/hydrotrack-project/hydrotrack/graphs/contributors

.. |downloads| image:: https://img.shields.io/pypi/dm/hydrotrack.svg
    :alt: Downloads
    :target: https://pypi.python.org/pypi/hydrotrack

.. |license| image:: https://img.shields.io/pypi/l/hydrotrack.svg
    :alt: License
    :target: https://github.com/hydrotrack-project/hydrotrack/blob/main/LICENSE

.. end-badges

Overview
=====================================================================

`hydrotrack` HydroTrack is a Python package designed to identify, track, analyze and forecast hydrological phenomena across a diverse range of datasets.
It offers a robust modular framework that seamlessly integrates various cutting-edge algorithms for feature identification, tracking, and comprehensive analyses.
One of HydroTrack's paramount advantages lies in its remarkable versatility, which liberates it from any reliance on specific input variables or grid structures.

Documentation
=====================================================================
For a more detailed information of `hydrotrack` package please read the user guide available `click here <https://github.com/hydrotrack-project/hydrotrack/blob/main/UserGuide.md>`_.


Download package
=====================================================================
Download package direct from github::

    git clone https://github.com/hydrotrack-project/hydrotrack/

Instalation
=====================================================================
Create a Python env using Anaconda3, Miniconda, Mamba, or etc.

Install env from environment.yml::

    cd hydrotrack
    conda env create -n hydrotrack --file environment.yml
    conda activate hydrotrack

or install package from local file::

	cd hydrotrack
	pip3 install -r requirements.txt

or just type::

	pip3 install hydrotrack

Example of usage
=====================================================================
`Open In Colab <https://colab.research.google.com/github/hydrotrack-project/hydrotrack/blob/main/examples/1_Introducing-Hydrotrack.ipynb>`_.

Support and Contact
=====================================================================
For support, email helvecio.neto@inpe.br, alan.calheiros@inpe.br
